{ config, pkgs, inputs, ... }:

{
  imports = [
    ./hardware-configuration.nix

    # GUI
    ../../modules/system/gui/hyprland.nix
    ../../modules/system/gui/cosmic.nix
    ../../modules/system/gui/cosmic-greeter.nix
    ../../modules/system/gui/steam.nix
    ../../modules/system/gui/thunar.nix
    
    # CLI
    ../../modules/system/cli/common.nix
    ../../modules/system/cli/docker.nix

    # Hardware
    # ../../modules/system/hardware/amd.nix
    ../../modules/system/hardware/bluetooth.nix
    ../../modules/system/hardware/firewall.nix
    ../../modules/system/hardware/garbage-collection.nix
    ../../modules/system/hardware/laptop.nix
    ../../modules/system/hardware/locale.nix
    ../../modules/system/hardware/printing.nix
    ../../modules/system/hardware/fprint.nix
    ../../modules/system/hardware/virt.nix
  ];

  nix.settings = {
    experimental-features = [ "nix-command" "flakes" ];

    substituters = [
      "https://nix-community.cachix.org"
      "https://cosmic.cachix.org/"
    ];

    trusted-public-keys = [
      "cosmic.cachix.org-1:Dya9IyXD4xdBehWjrkPv6rtxpmMdRel02smYzA85dPE="
    ];
  };

  # Configure hardware
  services.ratbagd.enable = true;

  # Bootloader.
  boot.loader.efi.canTouchEfiVariables = true;
  boot.loader.grub = {
    enable = true;
    efiSupport = true;
    device = "nodev";
    configurationLimit = 32;
  };

  networking.hostName = "xv-laptop"; # Define your hostname.

  users.users.xeovalyte = {
    isNormalUser = true;
    description = "Timo Boomers";
    extraGroups = [ "networkmanager" "wheel" "dialout" ];
  };

  nix.settings.trusted-users = [ "root" "xeovalyte" ];

  # Prevent system freeze on high load
  services.earlyoom = {
    enable = true;
  };

  boot.kernelPackages = pkgs.linuxPackages_latest;

  # Configure wacom tablet
  hardware.opentabletdriver = {
    enable = true;
    package = pkgs.unstable.opentabletdriver;
  };

  services.libinput.enable = true;
  services.fwupd.enable = true;

  system.stateVersion = "24.05";

}
